@@ -1,20 +1,20 @@
 package Text::Diff::Table;
 
-use 5.00503;
+use 5.006;
 use strict;
+use warnings;
 use Carp;
-use vars qw{$VERSION @ISA @EXPORT_OK};
-BEGIN {
-	$VERSION   = '1.36_01';
-	@ISA       = qw( Text::Diff::Base Exporter );
-	@EXPORT_OK = qw( expand_tabs );
-}
+use Text::Diff::Config;
+
+our $VERSION   = '1.41_01';
+our @ISA       = qw( Text::Diff::Base Exporter );
+our @EXPORT_OK = qw( expand_tabs );
 
 my %escapes = map {
     my $c =
         $_ eq '"' || $_ eq '$' ? qq{'$_'}
-	: $_ eq "\\"           ? qq{"\\\\"}
-	                       : qq{"$_"};
+    : $_ eq "\\"           ? qq{"\\\\"}
+                           : qq{"$_"};
     ( ord eval $c => $_ )
 } (
     map( chr, 32..126),
@@ -35,11 +35,11 @@ sub expand_tabs($) {
              my $spaces = " " x ( 8 - $count % 8  + 8 * length $2 );
              $count = 0;
              $spaces;
-	 }
-	 else {
-	     $count += length $3;
-	     $3;
-	}
+     }
+     else {
+         $count += length $3;
+         $3;
+    }
     }ge;
 
     return $s;
@@ -57,13 +57,16 @@ SCOPE: {
    ## use utf8 if available.  don't if not.
    my $escaper = <<'EOCODE';
       sub escape($) {
-	  use utf8;
-	  join "", map {
-	      $_ = ord;
-	      exists $escapes{$_}
-		  ? $escapes{$_}
-		  : sprintf( "\\x{%04x}", $_ );
-	  } split //, shift;
+      use utf8;
+      join "", map {
+          my $c = $_;
+          $_ = ord;
+          exists $escapes{$_}
+          ? $escapes{$_}
+          : $Text::Diff::Config::Output_Unicode 
+          ? $c
+          : sprintf( "\\x{%04x}", $_ );
+      } split //, shift;
       }
 
       1;
@@ -115,23 +118,23 @@ sub hunk {
                         $A->[1] eq $B->[1]  ? "="
                                             : "*";
         if ( $elt_type ne "*" ) {
-	    if ( $elt_type eq "=" || $A->[1] =~ /\S/ || $B->[1] =~ /\S/ ) {
-		$A->[1] = escape trim_trailing_line_ends expand_tabs $A->[1];
-		$B->[1] = escape trim_trailing_line_ends expand_tabs $B->[1];
-	    }
-	    else {
-		$A->[1] = escape $A->[1];
-		$B->[1] = escape $B->[1];
-	    }
+        if ( $elt_type eq "=" || $A->[1] =~ /\S/ || $B->[1] =~ /\S/ ) {
+        $A->[1] = escape trim_trailing_line_ends expand_tabs $A->[1];
+        $B->[1] = escape trim_trailing_line_ends expand_tabs $B->[1];
+        }
+        else {
+        $A->[1] = escape $A->[1];
+        $B->[1] = escape $B->[1];
+        }
         }
         else {
             ## not using \z here for backcompat reasons.
             $A->[1] =~ /^(\s*?)([^ \t].*?)?(\s*)(?![\n\r])$/s;
             my ( $l_ws_A, $body_A, $t_ws_A ) = ( $1, $2, $3 );
-	    $body_A = "" unless defined $body_A;
+        $body_A = "" unless defined $body_A;
             $B->[1] =~ /^(\s*?)([^ \t].*?)?(\s*)(?![\n\r])$/s;
             my ( $l_ws_B, $body_B, $t_ws_B ) = ( $1, $2, $3 );
-	    $body_B = "" unless defined $body_B;
+        $body_B = "" unless defined $body_B;
 
             my $added_escapes;
 
@@ -319,7 +322,7 @@ __END__
 
   use Text::Diff;
   
-  diff \@a, $b { STYLE => "Table" };
+  diff \@a, $b, { STYLE => "Table" };
 
 =head1 DESCRIPTION
 
@@ -378,6 +381,13 @@ Here's why the lines do or do not have whitespace escaped:
 Whether or not line 3 should have that tab character escaped is a judgement
 call; so far I'm choosing not to.
 
+=head1 UNICODE
+
+To output the raw unicode chracters consult the documentation of
+L<Text::Diff::Config>. You can set the C<DIFF_OUTPUT_UNICODE> environment
+variable to 1 to output it from the command line. For more information,
+consult this bug: L<https://rt.cpan.org/Ticket/Display.html?id=54214> .
+
 =head1 LIMITATIONS
 
 Table formatting requires buffering the entire diff in memory in order to
